/**
 * The {@link CoordCenter} centers all of the nodes as compactly as
 * possible. It produces generally poor layouts, but is very fast.
 *
 * @packageDocumentation
 */
import { Coord } from ".";
/**
 * A {@link Coord} that spaces every node out by node size, and then centers
 * them.
 *
 * This is a very fast operator, but doesn't produce very pleasing layouts.
 *
 * Create with {@link coordCenter}.
 */
export interface CoordCenter extends Coord<unknown, unknown> {
    /** @internal flag indicating that this is built in to d3dag and shouldn't error in specific instances */
    readonly d3dagBuiltin: true;
}
/**
 * Create a {@link CoordCenter}
 */
export declare function coordCenter(...args: never[]): CoordCenter;
