import { Coord } from ".";
/**
 * a {@link Coord} that tries to place nodes close to their parents
 *
 * Nodes that can't be placed at the mean of their parents' location, will be
 * spaced out with their priority equal to their degree.
 *
 * Create with {@link coordGreedy}.
 */
export interface CoordGreedy extends Coord<unknown, unknown> {
    /** @internal flag indicating that this is built in to d3dag and shouldn't error in specific instances */
    readonly d3dagBuiltin: true;
}
/**
 * create a new {@link CoordGreedy}
 *
 * This coordinate assignment operator tries to position nodes close to their
 * parents, but is more lenient in the constraint, so tends to be faster than
 * optimization based coordinate assignments, but runs much faster.
 *
 * @example
 *
 * ```ts
 * const layout = sugiyama().coord(coordGreedy());
 * ```
 */
export declare function coordGreedy(...args: never[]): CoordGreedy;
